==> webCDwriter-2.7.2.tar.bz2: webCDwriter-2.7.2/webCDcreator/PutDialog.java <==
/*
 * @(#)PutDialog.java
 *
 * This file is part of webCDwriter - Network CD/DVD Writing.
 *
 * Copyright (C) 1999-2005 Jrg P. M. Haeger
 *
 * webCDwriter is free software. See CDcreator.java for details.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A file transmission dialog.
 *
 * @version 20050826
 * @author Jrg P. M. Haeger
 */
class PutDialog extends JPanel {
	JLabel label;
	String labelBuffer = "";
	JProgressBar bar;
	JCheckBox ignoreAllUnreadableBox, shortenAllBox;

	PutDialog(JButton cancelButton) {
		setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 20));
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

		JPanel hp = new JPanel();
		hp.setLayout(
			new BoxLayout(hp, BoxLayout.X_AXIS));
		hp.setBorder(
			BorderFactory.createCompoundBorder(
				BorderFactory.createTitledBorder(
					CDcreator.i18n("file")),
				BorderFactory.createEmptyBorder(5, 5, 5, 5)));
		label = new JLabel(labelBuffer);
//		label.setEditable(false);
		hp.add(label);
		hp.add(Box.createHorizontalGlue());
		add(hp);

		add(Box.createRigidArea(new Dimension(500, 20)));

		bar = new JProgressBar();
		bar.setStringPainted(true);
		add(bar);

		add(Box.createVerticalStrut(20));

		hp = new JPanel();
		hp.setLayout(
			new BoxLayout(hp, BoxLayout.X_AXIS));
		hp.setBorder(
			BorderFactory.createCompoundBorder(
				BorderFactory.createTitledBorder(
					CDcreator.i18n("PutDialog.options")),
				BorderFactory.createEmptyBorder(5, 5, 5, 5)));
		ignoreAllUnreadableBox = new JCheckBox(
			CDcreator.i18n("PutDialog.ignoreAllUnreadable"), false);
		hp.add(ignoreAllUnreadableBox);
		hp.add(Box.createHorizontalStrut(20));
		shortenAllBox = new JCheckBox(
			CDcreator.i18n("PutDialog.shortenAll"), false);
		hp.add(shortenAllBox);
		hp.add(Box.createHorizontalGlue());
		add(hp);

		add(Box.createVerticalGlue());

		JPanel buttons = new JPanel();
		buttons.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		buttons.setLayout(new FlowLayout(FlowLayout.CENTER));
		buttons.add(cancelButton);
		add(buttons);
	}

	public void setMessage(String str) {
		if (str.length() > 70) {
			int p = str.lastIndexOf("/");
			if (p >= 0)
				str = str.substring(0, 70 - 2 - (str.length() - p))
					+ "..." + str.substring(p);
		}

		synchronized(label) {
			boolean refresh = labelBuffer.length() == 0;
			labelBuffer = str;
			if (!refresh)
				return;
		}

		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				synchronized(label) {
					label.setText(labelBuffer);
//					label.setCaretPosition(labelBuffer.length());
					labelBuffer = "";
				}
			}
		});
	}

	public void setRange(final int a, final int b) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				bar.setMinimum(a);
				bar.setMaximum(b);
			}
		});
	}

	public void setProgress(final int n) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				bar.setValue(n);
			}
		});
	}
}

==> webCDwriter-2.7.3.tar.bz2: webCDwriter-2.7.3/webCDcreator/PutDialog.java <==
/*
 * @(#)PutDialog.java
 *
 * This file is part of webCDwriter - Network CD/DVD Writing.
 *
 * Copyright (C) 1999-2005 Jrg P. M. Haeger
 *
 * webCDwriter is free software. See CDcreator.java for details.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A file transmission dialog.
 *
 * @version 20051108
 * @author Jrg P. M. Haeger
 */
class PutDialog extends JPanel {
	JLabel label;
	String labelBuffer = "";
	JProgressBar bar;
	JCheckBox ignoreAllUnreadableBox, shortenAllBox;

	PutDialog(JButton cancelButton) {
		setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 20));
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

		JPanel hp = new JPanel();
		hp.setLayout(
			new BoxLayout(hp, BoxLayout.X_AXIS));
		hp.setBorder(
			BorderFactory.createCompoundBorder(
				BorderFactory.createTitledBorder(
					CDcreator.i18n("file")),
				BorderFactory.createEmptyBorder(5, 5, 5, 5)));
		label = new JLabel(labelBuffer);
//		label.setEditable(false);
		hp.add(label);
		hp.add(Box.createHorizontalGlue());
		add(hp);

		add(Box.createRigidArea(new Dimension(500, 20)));

		bar = new JProgressBar();
		bar.setStringPainted(true);
		add(bar);

		add(Box.createVerticalStrut(20));

		hp = new JPanel();
		hp.setLayout(
			new BoxLayout(hp, BoxLayout.X_AXIS));
		hp.setBorder(
			BorderFactory.createCompoundBorder(
				BorderFactory.createTitledBorder(
					CDcreator.i18n("PutDialog.options")),
				BorderFactory.createEmptyBorder(5, 5, 5, 5)));
		ignoreAllUnreadableBox = new JCheckBox(
			CDcreator.i18n("PutDialog.ignoreAllUnreadable"), false);
		hp.add(ignoreAllUnreadableBox);
		hp.add(Box.createHorizontalStrut(20));
		shortenAllBox = new JCheckBox(
			CDcreator.i18n("PutDialog.shortenAll"), false);
		hp.add(shortenAllBox);
		hp.add(Box.createHorizontalGlue());
		add(hp);

		add(Box.createVerticalGlue());

		JPanel buttons = new JPanel();
		buttons.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		buttons.setLayout(new FlowLayout(FlowLayout.CENTER));
		buttons.add(cancelButton);
		add(buttons);
	}

	public void setMessage(String str) {
		final int maxLength = 70;
		final int length = str.length();
		if (length > maxLength) {
			final int p = str.lastIndexOf("/");
			if (p < 0 || length - p > maxLength / 2)
				str = str.substring(length - maxLength);
			else
				str = str.substring(0, maxLength - 3 - (length - p))
					+ "..." + str.substring(p);
		}

		synchronized(label) {
			boolean refresh = labelBuffer.length() == 0;
			labelBuffer = str;
			if (!refresh)
				return;
		}

		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				synchronized(label) {
					label.setText(labelBuffer);
//					label.setCaretPosition(labelBuffer.length());
					labelBuffer = "";
				}
			}
		});
	}

	public void setRange(final int a, final int b) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				bar.setMinimum(a);
				bar.setMaximum(b);
			}
		});
	}

	public void setProgress(final int n) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				bar.setValue(n);
				CDcreator.setTitle((int) (100 * bar.getPercentComplete()));
			}
		});
	}
}
